ams.core.service.NumHstack
==========================

.. currentmodule:: ams.core.service

.. autoclass:: NumHstack

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: _generated/

   
       
       
          ~NumHstack.assign_memory
       
       
          ~NumHstack.evaluate
       
       
          ~NumHstack.get_names
       
       
          ~NumHstack.parse
       
       
          ~NumHstack.update
       
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree: _generated/

   
      ~NumHstack.class_name
      ~NumHstack.n
      ~NumHstack.shape
      ~NumHstack.size
      ~NumHstack.v
      ~NumHstack.v0
      ~NumHstack.v1
   
   